Windows
=======

The following compiled libraries (release mode) and SWIG-generated wrappers should be copied here:

- _fmippim.pyd
- _fmippex.pyd
- fmippim.dll
- fmippex.dll
- sundials_cvode.dll
- sundials_nvecserial.dll
- Visual Studio runtime libraries (e.g., msvcp140.dll & vcruntime.dll)
